Constants class

Constructors

Constants({required String authorization, required String order, required String keys, required String wallet})
Constants.custom({required String authorization, required String order, required String keys, required String wallet})
factory
Constants.production()
factory
Constants.staging()
factory

Properties

authorization → String
final
hashCode → int
The hash code for this object.
no setterinherited
keys → String
final
order → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wallet → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

acceptBaseUrl → const String